import csv
from collections import Counter
import datetime

def load_crimes():
    crimes_file = open('crime.csv')
    crimes_reader = csv.DictReader(crimes_file)

    # return crimes_reader

    crimes = []
    for crime in crimes_reader:
        crimes.append(crime)

    return crimes

def count_lengths(crimes):
    lengths = Counter()
    for crime in crimes:
        length = sum(map(len, crime.values()))
        lengths[length] += 1

    for l in sorted(lengths):
        print l, lengths[l]


def count_new_lines(s):
    return s.count('\n')

def count_lines(crimes):
    lines = 0
    for crime in crimes:
        extra_lines = sum(map(count_new_lines, crime.values()))
        lines += 1 + extra_lines
    print "LINES", lines

def crimes_summary(crimes):
    summary = Counter()
    for crime in crimes:
        summary[crime['Class Description']] += 1

    return summary

def filter_crimes(crimes, class_description):
    result = []

    for crime in crimes:
        if crime['Class Description'] == class_description:
            result.append(crime)

    return result

    # return [crime for crime in crimes 
    #         if crime['Class Description'] == class_description]


def to_datetime(date_string):
    return datetime.datetime.strptime(date_string,'%m/%d/%Y %I:%M:%S %p')    

if __name__ == '__main__':
    assert to_datetime('08/25/2014 08:04:00 PM').hour == 20

weekdays = ['Mon', 'Tue', 'Wed', 'Thu', 'Fri', 'Sat', 'Sun']

def day_of_week(d):
    return weekdays[d.weekday()]

timesofday = ['Morning', 'Afternoon', 'Evening', 'Night']

def time_of_day(d):
    if d.hour >= 6 and d.hour < 12:
        return timesofday[0]
    elif d.hour >= 12 and d.hour < 18:
        return timesofday[1]
    elif d.hour >= 18 and d.hour < 22:
        return timesofday[2]
    else:
        return timesofday[3]
    
def crimes_day_summary(crimes):
    summary = Counter()

    for crime in crimes:
        d = to_datetime(crime['Dispatch Date / Time'])
        summary[day_of_week(d)] += 1

    return summary

def crimes_time_summary(crimes):
    summary = Counter()

    for crime in crimes:
        d = to_datetime(crime['Dispatch Date / Time'])
        summary[time_of_day(d)] += 1

    return summary


if __name__ == '__main__':
    crimes = load_crimes()
    # count_lengths(crimes)
    # count_lines(crimes)
    drunk_driving_crimes = filter_crimes(crimes,
                                         'DRIVING UNDER THE INFLUENCE')
    day_summary = crimes_day_summary(drunk_driving_crimes)

    print "DRUNK'N'DRIVING BY WEEKDAY"
    for (day, crime_count) in day_summary.most_common():
        print day, crime_count

    time_summary = crimes_time_summary(drunk_driving_crimes)
    print "DRUNK'N'DRIVING BY TIME OF DAY"
    for (t, crime_count) in time_summary.most_common():
        print t, crime_count
